@@ -9,26 +9,26 @@ print(pydicom.config.image_handlers)
 class ImageIO:
     # private
     @staticmethod
-    def ensure_even(self, stream):
+    def ensure_even(stream):
         # Very important for some viewers
         if len(stream) % 2:
             return stream + b"\x00"
         return stream
     @staticmethod
-    def loadImage(self, file):
+    def loadImage(file):
         ds = pydicom.dcmread(file)
         pixel_array = np.uint16(ds.pixel_array)
         cols = ds.Columns
         rows = ds.Rows
         return Image(pixel_array, cols, rows, ds)
     @staticmethod
-    def buildFile(self, image, saveName):
+    def buildFile(image, saveName):
         # TODO : edit height and width elements
         dataset = ImageIO.buildDataSetImplicitVRLittleEndian(image)
         dataset.save_as(saveName)
         return saveName
     @staticmethod
-    def buildDataSetJPEG2000(self, image):
+    def buildDataSetJPEG2000(image):
         from io import BytesIO
         from PIL import Image as PImage
         dataset = image.dataset
@@ -43,7 +43,7 @@ class ImageIO:
         dataset.is_implicit_VR = False
         return dataset
     @staticmethod
-    def buildDataSetImplicitVRLittleEndian(self, image):
+    def buildDataSetImplicitVRLittleEndian(image):
         dataset = image.dataset
         pixels = image.pixelData
         dataset.PixelData = pixels.tobytes()
